==> reshep-0.1.0.tgz: package/lib/__tests__/shape-from.js <==
'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _enzyme = require('enzyme');

require('jest-enzyme');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _ = require('./../');

var _util = require('./../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('reshep > shapeFrom', function () {
  test('To throw a TypeError if pathMap is not an object.', function () {
    var errType = function errType() {
      return TypeError;
    };
    var errMsg = function errMsg(type) {
      return 'Expected `pathMap` to be an object. ' + ('`pathMap` is type ' + type + ' instead.');
    };

    var testErr = function testErr(x) {
      expect(function () {
        return (0, _.shapeFrom)(x);
      }).toThrow(errType());
      expect(function () {
        return (0, _.shapeFrom)(x);
      }).toThrow(errMsg((0, _util.typeOf)(x)));
    };

    ['foo', 1, null, undefined, []].forEach(testErr);
  });

  test('Returns a higher-order component.', function () {
    var Base = function Base() {
      return _react2.default.createElement('p', {}, 'foo');
    };

    var HOC = (0, _.shapeFrom)({})(Base);

    var wrapped = (0, _enzyme.mount)(_react2.default.createElement(HOC, {}));

    expect(wrapped).toContainReact(_react2.default.createElement(Base));
  });

  test('Component maps deeply nested props for each entry in `pathMap`.', function () {
    var props = {
      a: { b: { c: 1 } },
      d: { e: 2 },
      f: 3
    };

    var pathMap = {
      'a.b.c': 'a',
      'd.e': 'b.c',
      'f': 'd.e.f'
    };

    var Base = jest.fn();
    Base.mockReturnValue(null);

    var HOC = (0, _.shapeFrom)(pathMap)(Base);

    (0, _enzyme.mount)(_react2.default.createElement(HOC, props));

    var baseProps = Base.mock.calls[0][0];

    Object.keys(pathMap).map(function (k) {
      return [k, pathMap[k]];
    }).map(function (paths) {
      return paths.map(function (p) {
        return p.split('.');
      });
    }).map(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          from = _ref2[0],
          to = _ref2[1];

      return [(0, _util.getPath)(from, props), (0, _util.getPath)(to, baseProps)];
    }).forEach(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
          from = _ref4[0],
          to = _ref4[1];

      return expect(from).toEqual(to);
    });
  });

  test('Props received by base component only contains new paths.', function () {
    var props = {
      a: { b: { c: 1 } },
      d: { e: 2 },
      f: 3
    };

    var pathMap = {
      'a.b.c': 'a',
      'd.e': 'b.c',
      'f': 'd.e.f'
    };

    var Base = jest.fn();
    Base.mockReturnValue(null);

    var HOC = (0, _.shapeFrom)(pathMap)(Base);

    (0, _enzyme.mount)(_react2.default.createElement(HOC, props));

    var baseProps = Base.mock.calls[0][0];

    var expected = {
      a: 1,
      b: { c: 2 },
      d: { e: { f: 3 } }
    };

    expect(baseProps).toEqual(expected);
  });
});

==> reshep-0.1.2.tgz: package/lib/__tests__/shape-from.js <==
'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _enzyme = require('enzyme');

require('jest-enzyme');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _ = require('./../');

var _util = require('./../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('reshep > shapeFrom', function () {
  test('Throws a TypeError if pathMap is not an object.', function () {
    var errType = function errType() {
      return TypeError;
    };
    var errMsg = function errMsg(type) {
      return 'Expected `pathMap` to be an object. ' + ('`pathMap` is type ' + type + ' instead.');
    };

    var testErr = function testErr(x) {
      expect(function () {
        return (0, _.shapeFrom)(x);
      }).toThrow(errType());
      expect(function () {
        return (0, _.shapeFrom)(x);
      }).toThrow(errMsg((0, _util.typeOf)(x)));
    };

    ['foo', 1, null, undefined, []].forEach(testErr);
  });

  test('Returns a higher-order component.', function () {
    var Base = function Base() {
      return _react2.default.createElement('p', {}, 'foo');
    };

    var HOC = (0, _.shapeFrom)({})(Base);

    var wrapped = (0, _enzyme.mount)(_react2.default.createElement(HOC, {}));

    expect(wrapped).toContainReact(_react2.default.createElement(Base));
  });

  test('Component maps deeply nested props for each entry in `pathMap`.', function () {
    var props = {
      a: { b: { c: 1 } },
      d: { e: 2 },
      f: 3
    };

    var pathMap = {
      'a.b.c': 'a',
      'd.e': 'b.c',
      'f': 'd.e.f'
    };

    var Base = jest.fn();
    Base.mockReturnValue(null);

    var HOC = (0, _.shapeFrom)(pathMap)(Base);

    (0, _enzyme.mount)(_react2.default.createElement(HOC, props));

    var baseProps = Base.mock.calls[0][0];

    Object.keys(pathMap).map(function (k) {
      return [k, pathMap[k]];
    }).map(function (paths) {
      return paths.map(function (p) {
        return p.split('.');
      });
    }).map(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          from = _ref2[0],
          to = _ref2[1];

      return [(0, _util.getPath)(from, props), (0, _util.getPath)(to, baseProps)];
    }).forEach(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
          from = _ref4[0],
          to = _ref4[1];

      return expect(from).toEqual(to);
    });
  });

  test('Props received by base component only contains new paths.', function () {
    var props = {
      a: { b: { c: 1 } },
      d: { e: 2 },
      f: 3
    };

    var pathMap = {
      'a.b.c': 'a',
      'd.e': 'b.c',
      'f': 'd.e.f'
    };

    var Base = jest.fn();
    Base.mockReturnValue(null);

    var HOC = (0, _.shapeFrom)(pathMap)(Base);

    (0, _enzyme.mount)(_react2.default.createElement(HOC, props));

    var baseProps = Base.mock.calls[0][0];

    var expected = {
      a: 1,
      b: { c: 2 },
      d: { e: { f: 3 } }
    };

    expect(baseProps).toEqual(expected);
  });
});
